@@ -10,4 +10,4 @@ from ._version import get_versions
 
 __version__ = get_versions()["version"]
 del get_versions
-from omigami_client.omigami_client import OmigamiClient
+from omigami_client.spec2vec import Spec2VecClient
